/***************************************************************************//**
 *   @file   Main.c
 *   @brief  Implementation of the program's main function.
 *   @author DBogdan (dragos.bogdan@analog.com)
********************************************************************************
 * Copyright 2012(c) Analog Devices, Inc.
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *  - Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  - Neither the name of Analog Devices, Inc. nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *  - The use of this software may or may not infringe the patent rights
 *    of one or more patent holders.  This license does not release you
 *    from the requirement that you obtain separate licenses from these
 *    patent holders to use this software.
 *  - Use of the software either in source or binary form, must be run
 *    on or directly connected to an Analog Devices Inc. component.
 *
 * THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
********************************************************************************
 *   SVN Revision: 590
*******************************************************************************/

/******************************************************************************/
/* Include Files                                                              */
/******************************************************************************/
#include "YRDKRL78G13.h"    // YRDKRX62N definitions.
#include "ST7579.h"         // ST7579 definitions.
#include "AD7291.h"         // AD7291 definitions.

/******************************************************************************/
/* Option Bytes                                                               */
/******************************************************************************/
#pragma location = "OPTBYTE"
__root const uint8_t opbyte0 = 0x00U;
#pragma location = "OPTBYTE"
__root const uint8_t opbyte1 = 0xFFU;
#pragma location = "OPTBYTE"
__root const uint8_t opbyte2 = 0xE8U;
#pragma location = "OPTBYTE"
__root const uint8_t opbyte3 = 0x04U;

/******************************************************************************/
/* Security ID                                                                */
/******************************************************************************/
#pragma location = "SECUID"
__root const uint8_t secuid[10] = 
    {0x00U, 0x00U, 0x00U, 0x00U, 0x00U, 0x00U, 0x00U, 0x00U, 0x00U, 0x00U};

/******************************************************************************/
/* Variables Declarations                                                     */
/******************************************************************************/
const unsigned char adiLogo [2 * 19] =
	{ 0xFF, 0xFF, 0xFF, 0x03, 0x03, 0x03, 0x07, 0x07,
	  0x0F, 0x0F, 0x1F, 0x1F, 0x3F, 0x3F, 0x7F, 0x7F,
	  0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0xC0,
	  0xC0, 0xE0, 0xE0, 0xF0, 0xF0, 0xF8, 0xF8, 0xFC,
	  0xFC, 0xFE, 0xFE, 0xFF, 0xFF, 0xFF };	// ADI Logo.
float           temperature = 0;
unsigned short  tempDisplay = 0;
unsigned short  command     = 0;
unsigned short  data[8]     = {0, };

/***************************************************************************//**
 * @brief Creates a delay of miliseconds.
 *
 * @param mSeconds - time in miliseconds.
 *
 * @return None.
*******************************************************************************/
void DelayMs(unsigned long mSeconds)
{
    unsigned long time = 0;
    
    R_TAU0_Channel0_Start();
    while(time < mSeconds)
    {
        if(TMIF00 == 1)
        {
            time++;
            TMIF00 = 0;
        }
    }
    R_TAU0_Channel0_Stop();
}

/***************************************************************************//**
 * @brief Main function.
 *
 * @return None.
*******************************************************************************/
void main(void)
{
    YRDKRL78G13_Init();
    ST7579_Init();
    ST7579_Image(2, 0, adiLogo, 19, 16);
    ST7579_String(2, 21, "ANALOG");
    ST7579_String(3, 21, "DEVICES");
    ST7579_String(4, 0, "wiki.analog.com");
    DelayMs(2000);
    ST7579_Clear();
    ST7579_Image(0, 0,adiLogo, 19, 16);	
    ST7579_String(0, 22, "ST7579 OK");
    /* Initializes the I2C communication peripheral and configures AD7291. */
    if(AD7291_Init())
    {
        ST7579_String(1, 22, "AD7291 OK");
    }
    else
    {
        ST7579_String(1, 22, "AD7291 Err");
    }
    /* Select analog inputs CH1 and CH7 to be converted */
    command = AD7291_COMMAND_DELAY |
              AD7291_COMMAND_CH(1) |
              AD7291_COMMAND_CH(7);
    AD7291_SetRegisterValue(AD7291_REG_COMMAND, command);
    while(1)
    {
        temperature = AD7291_GetDegreesTemp();
        /* Display the temperature with 2 decimals */
        tempDisplay = (temperature * 100);
        ST7579_String(3, 10, "Temp:   ,   C");
        ST7579_Number(3, 52, (tempDisplay / 100), 2);
        ST7579_Number(3, 70, (tempDisplay % 100), 2);
        /* Display the conversion results. */
        ST7579_String(4, 3, "C0:     C4:    ");
        ST7579_String(5, 3, "C1:     C5:    ");
        ST7579_String(6, 3, "C2:     C6:    ");
        ST7579_String(7, 3, "C3:     C7:    ");
        data[0] = 0;
        data[1] = 0;
        data[2] = 0;
        data[3] = 0;
        data[4] = 0;
        data[5] = 0;
        data[6] = 0;
        data[7] = 0;
        AD7291_GetVoltageConversionResults(data);
        ST7579_HexNumber(4, 37, data[0], 3);
        ST7579_HexNumber(4, 84, data[4], 3);
        ST7579_HexNumber(5, 37, data[1], 3);
        ST7579_HexNumber(5, 84, data[5], 3);
        ST7579_HexNumber(6, 37, data[2], 3);
        ST7579_HexNumber(6, 84, data[6], 3);
        ST7579_HexNumber(7, 37, data[3], 3);
        ST7579_HexNumber(7, 84, data[7], 3);
        /* Measurements are made twice per second */
        DelayMs(500);
    }
}
